@@ -20,6 +20,14 @@ CreateIndexDialog::CreateIndexDialog(DBBrowserDB* db, QWidget* parent)
         dbobjs.insert((*it).getname(), (*it));
     for(QMultiMap<QString, DBBrowserObject>::ConstIterator it=dbobjs.begin(); it != dbobjs.end(); ++it)
         ui->comboTableName->addItem(QIcon(QString(":icons/table")), (*it).getname());
+
+    QHeaderView *tableHeaderView = ui->tableIndexColumns->horizontalHeader();
+
+#if QT_VERSION < 0x050000
+    tableHeaderView->setResizeMode(0, QHeaderView::Stretch);
+#else
+    tableHeaderView->setSectionResizeMode(0, QHeaderView::Stretch);
+#endif
 }
 
 CreateIndexDialog::~CreateIndexDialog()
