@@ -12,6 +12,7 @@ class EditDialog;
 class QIntValidator;
 class QLabel;
 class QModelIndex;
+class QPersistentModelIndex;
 class SqliteTableModel;
 class DbStructureModel;
 class QNetworkReply;
@@ -103,11 +104,13 @@ private:
     Ui::MainWindow* ui;
 
     SqliteTableModel* m_browseTableModel;
+    SqliteTableModel* m_currentTabTableModel;
     SqliteTableModel* m_currentPlotModel;
     QMenu *popupTableMenu;
     QMenu *recentFilesMenu;
     QMenu *popupSaveSqlFileMenu;
     QMenu* popupBrowseDataHeaderMenu;
+    QMenu* popupRecordMenu;
 
     QLabel* statusEncodingLabel;
     QLabel* statusEncryptionLabel;
@@ -121,7 +124,6 @@ private:
 
     QMap<QString, BrowseDataTableSettings> browseTableSettings;
 
-    EditDialog* editWin;
     EditDialog* editDock;
     QIntValidator* gotoValidator;
 
@@ -151,17 +153,19 @@ public slots:
     void dbState(bool dirty);
     void browseRefresh();
     void jumpToRow(const QString& table, QString column, const QByteArray& value);
+    void switchToBrowseDataTab(QString tableToBrowse = QString());
 
 private slots:
     void createTreeContextMenu(const QPoint & qPoint);
     void changeTreeSelection();
     void fileNew();
     void populateStructure();
-    void populateTable(const QString& tablename);
-    void resetBrowser();
+    void populateTable(QString tablename);
+    void resetBrowser(bool reloadTable = true);
     bool fileClose();
     void addRecord();
     void deleteRecord();
+    void dittoRecord();
     void selectTableLine( int lineToSelect );
     void navigatePrevious();
     void navigateNext();
@@ -176,8 +180,8 @@ private slots:
     void editTable();
     void helpWhatsThis();
     void helpAbout();
-    void updateRecordText(int row, int col, const QByteArray& newtext);
-    void editWinAway();
+    void updateRecordText(const QPersistentModelIndex& idx, const QByteArray& text, bool isBlob);
+    void toggleEditDock(bool visible);
     void dataTableSelectionChanged(const QModelIndex& index);
     void doubleClickTable(const QModelIndex& index);
     void executeQuery();
@@ -185,6 +189,8 @@ private slots:
     void exportTableToCSV();
     void fileSave();
     void fileRevert();
+    void on_actionOpen_Remote_triggered();
+    void on_actionSave_Remote_triggered();
     void exportDatabaseToSQL();
     void importDatabaseFromSQL();
     void openPreferences();
@@ -208,6 +214,7 @@ private slots:
     void on_butSavePlot_clicked();
     void on_actionWiki_triggered();
     void on_actionBug_report_triggered();
+    void on_actionSqlCipherFaq_triggered();
     void on_actionWebsite_triggered();
     void updateBrowseDataColumnWidth(int section, int /*old_size*/, int new_size);
     bool loadProject(QString filename = QString());
@@ -215,16 +222,17 @@ private slots:
     void fileAttach();
     void updateFilter(int column, const QString& value);
     void editEncryption();
-    void switchToBrowseDataTab();
     void on_buttonClearFilters_clicked();
     void copyCurrentCreateStatement();
     void on_comboLineType_currentIndexChanged(int index);
     void on_comboPointShape_currentIndexChanged(int index);
     void showDataColumnPopupMenu(const QPoint& pos);
+    void showRecordPopupMenu(const QPoint& pos);
     void editDataColumnDisplayFormat();
     void showRowidColumn(bool show);
     void browseDataSetTableEncoding(bool forAllTables = false);
     void browseDataSetDefaultTableEncoding();
+    void browseDataFetchAllData();
 };
 
 #endif
