@@ -60,12 +60,27 @@ void PreferencesDialog::loadSettings()
     ui->comboDefaultLocation->setCurrentIndex(getSettingsValue("db", "savedefaultlocation").toInt());
     ui->locationEdit->setText(getSettingsValue("db", "defaultlocation").toString());
     ui->checkUpdates->setChecked(getSettingsValue("checkversion", "enabled").toBool());
+    ui->checkUseRemotes->setChecked(getSettingsValue("MainWindow", "remotemenu").toBool());
     ui->checkHideSchemaLinebreaks->setChecked(getSettingsValue("db", "hideschemalinebreaks").toBool());
     ui->foreignKeysCheckBox->setChecked(getSettingsValue("db", "foreignkeys").toBool());
     ui->spinPrefetchSize->setValue(getSettingsValue("db", "prefetchsize").toInt());
     ui->editDatabaseDefaultSqlText->setText(getSettingsValue("db", "defaultsqltext").toString());
 
-    ui->comboDataBrowserFont->setCurrentIndex(ui->comboEditorFont->findText(getSettingsValue("databrowser", "font").toString()));
+    ui->defaultFieldTypeComboBox->addItems(sqlb::Field::Datatypes);
+
+    int defaultFieldTypeIndex = getSettingsValue("db", "defaultfieldtype").toInt();
+
+    if (defaultFieldTypeIndex < sqlb::Field::Datatypes.count())
+    {
+        ui->defaultFieldTypeComboBox->setCurrentIndex(defaultFieldTypeIndex);
+    }
+
+    // Gracefully handle the preferred Data Browser font not being available
+    int matchingFont = ui->comboDataBrowserFont->findText(getSettingsValue("databrowser", "font").toString(), Qt::MatchExactly);
+    if (matchingFont == -1)
+        matchingFont = ui->comboDataBrowserFont->findText(getSettingsDefaultValue("databrowser", "font").toString());
+    ui->comboDataBrowserFont->setCurrentIndex(matchingFont);
+
     ui->spinDataBrowserFontSize->setValue(getSettingsValue("databrowser", "fontsize").toInt());
     loadColorSetting(ui->fr_null_fg, "null_fg");
     loadColorSetting(ui->fr_null_bg, "null_bg");
@@ -74,8 +89,10 @@ void PreferencesDialog::loadSettings()
     loadColorSetting(ui->fr_bin_fg, "bin_fg");
     loadColorSetting(ui->fr_bin_bg, "bin_bg");
 
+    ui->spinSymbolLimit->setValue(getSettingsValue("databrowser", "symbol_limit").toInt());
     ui->txtNull->setText(getSettingsValue("databrowser", "null_text").toString());
     ui->editFilterEscape->setText(getSettingsValue("databrowser", "filter_escape").toString());
+    ui->spinFilterDelay->setValue(getSettingsValue("databrowser", "filter_delay").toInt());
 
     for(int i=0; i < ui->treeSyntaxHighlighting->topLevelItemCount(); ++i)
     {
@@ -91,10 +108,17 @@ void PreferencesDialog::loadSettings()
             ui->treeSyntaxHighlighting->topLevelItem(i)->setCheckState(5, getSettingsValue("syntaxhighlighter", name + "_underline").toBool() ? Qt::Checked : Qt::Unchecked);
         }
     }
-    ui->comboEditorFont->setCurrentIndex(ui->comboEditorFont->findText(getSettingsValue("editor", "font").toString()));
+
+    // Gracefully handle the preferred Editor font not being available
+    matchingFont = ui->comboEditorFont->findText(getSettingsValue("editor", "font").toString(), Qt::MatchExactly);
+    if (matchingFont == -1)
+        matchingFont = ui->comboDataBrowserFont->findText(getSettingsDefaultValue("editor", "font").toString());
+    ui->comboEditorFont->setCurrentIndex(matchingFont);
+
     ui->spinEditorFontSize->setValue(getSettingsValue("editor", "fontsize").toInt());
     ui->spinTabSize->setValue(getSettingsValue("editor", "tabsize").toInt());
     ui->spinLogFontSize->setValue(getSettingsValue("log", "fontsize").toInt());
+    ui->checkAutoCompletion->setChecked(getSettingsValue("editor", "auto_completion").toBool());
     ui->checkErrorIndicators->setChecked(getSettingsValue("editor", "error_indicators").toBool());
     ui->checkHorizontalTiling->setChecked(getSettingsValue("editor", "horizontal_tiling").toBool());
 
@@ -113,6 +137,9 @@ void PreferencesDialog::saveSettings()
     setSettingsValue("db", "prefetchsize", ui->spinPrefetchSize->value());
     setSettingsValue("db", "defaultsqltext", ui->editDatabaseDefaultSqlText->text());
 
+    setSettingsValue("db", "defaultfieldtype", ui->defaultFieldTypeComboBox->currentIndex());
+
+    setSettingsValue("MainWindow", "remotemenu", ui->checkUseRemotes->isChecked());
     setSettingsValue("checkversion", "enabled", ui->checkUpdates->isChecked());
 
     setSettingsValue("databrowser", "font", ui->comboDataBrowserFont->currentText());
@@ -123,8 +150,10 @@ void PreferencesDialog::saveSettings()
     saveColorSetting(ui->fr_reg_bg, "reg_bg");
     saveColorSetting(ui->fr_bin_fg, "bin_fg");
     saveColorSetting(ui->fr_bin_bg, "bin_bg");
+    setSettingsValue("databrowser", "symbol_limit", ui->spinSymbolLimit->value());
     setSettingsValue("databrowser", "null_text", ui->txtNull->text());
     setSettingsValue("databrowser", "filter_escape", ui->editFilterEscape->text());
+    setSettingsValue("databrowser", "filter_delay", ui->spinFilterDelay->value());
 
     for(int i=0; i < ui->treeSyntaxHighlighting->topLevelItemCount(); ++i)
     {
@@ -138,6 +167,7 @@ void PreferencesDialog::saveSettings()
     setSettingsValue("editor", "fontsize", ui->spinEditorFontSize->value());
     setSettingsValue("editor", "tabsize", ui->spinTabSize->value());
     setSettingsValue("log", "fontsize", ui->spinLogFontSize->value());
+    setSettingsValue("editor", "auto_completion", ui->checkAutoCompletion->isChecked());
     setSettingsValue("editor", "error_indicators", ui->checkErrorIndicators->isChecked());
     setSettingsValue("editor", "horizontal_tiling", ui->checkHorizontalTiling->isChecked());
 
@@ -213,7 +243,7 @@ QVariant PreferencesDialog::getSettingsDefaultValue(const QString& group, const
 
     // db/hideschemalinebreaks?
     if(group == "db" && name == "hideschemalinebreaks")
-        return false;
+        return true;
 
     // db/foreignkeys?
     if(group == "db" && name == "foreignkeys")
@@ -227,6 +257,18 @@ QVariant PreferencesDialog::getSettingsDefaultValue(const QString& group, const
     if(group == "db" && name == "defaultsqltext")
         return "";
 
+    // exportcsv/firstrowheader?
+    if(group == "exportcsv" && name == "firstrowheader")
+        return true;
+
+    // exportcsv/separator?
+    if(group == "exportcsv" && name == "separator")
+        return ',';
+
+    // exportcsv/quotecharacter?
+    if(group == "exportcsv" && name == "quotecharacter")
+        return '"';
+
     // MainWindow/geometry?
     if(group == "MainWindow" && name == "geometry")
         return "";
@@ -235,6 +277,10 @@ QVariant PreferencesDialog::getSettingsDefaultValue(const QString& group, const
     if(group == "MainWindow" && name == "windowState")
         return "";
 
+    // Enable the File → Remote menu by default
+    if(group == "MainWindow" && name == "remotemenu")
+        return true;
+
     // SQLLogDock/Log?
     if(group == "SQLLogDock" && name == "Log")
         return "Application";
@@ -255,24 +301,28 @@ QVariant PreferencesDialog::getSettingsDefaultValue(const QString& group, const
     if(group == "databrowser")
     {
         if(name == "font")
-            return "Sans Serif";
+            return QFont().defaultFamily();
         if(name == "fontsize")
             return 10;
-        if (name == "null_text")
+        if(name == "symbol_limit")
+            return 5000;
+        if(name == "null_text")
             return "NULL";
-        if (name == "filter_escape")
+        if(name == "filter_escape")
             return "\\";
-        if (name == "null_fg_colour")
+        if(name == "filter_delay")
+            return 200;
+        if(name == "null_fg_colour")
             return QColor(Qt::lightGray).name();
-        if (name == "null_bg_colour")
+        if(name == "null_bg_colour")
             return QColor(Qt::white).name();
-        if (name == "reg_fg_colour")
+        if(name == "reg_fg_colour")
             return QColor(Qt::black).name();
-        if (name == "reg_bg_colour")
+        if(name == "reg_bg_colour")
             return QColor(Qt::white).name();
-        if (name == "bin_fg_colour")
+        if(name == "bin_fg_colour")
             return QColor(Qt::lightGray).name();
-        if (name == "bin_bg_colour")
+        if(name == "bin_bg_colour")
             return QColor(Qt::white).name();
     }
 
@@ -313,7 +363,11 @@ QVariant PreferencesDialog::getSettingsDefaultValue(const QString& group, const
 
     // editor/font?
     if(group == "editor" && name == "font")
-        return "Monospace";
+    {
+        QFont font("Monospace");
+        font.setStyleHint(QFont::TypeWriter);
+        return QFontInfo(font).family();
+    }
 
     // editor/fontsize or log/fontsize?
     if((group == "editor" || group == "log") && name == "fontsize")
@@ -327,6 +381,10 @@ QVariant PreferencesDialog::getSettingsDefaultValue(const QString& group, const
         }
     }
 
+    // editor/auto_completion?
+    if(group == "editor" && name == "auto_completion")
+        return true;
+
     // editor/error_indicators?
     if(group == "editor" && name == "error_indicators")
         return true;
