@@ -89,39 +89,6 @@ QString rtrimChar(const QString& s, QChar c) {
         r.chop(1);
     return r;
 }
-
-QString removeComments(QString s)
-{
-    // Feel free to fix all the bugs this probably contains or just replace this function entirely by
-    // a 'simple' regular expression. I know there're better ways to do this...
-
-    // This function removes any single line comments (starting with '--') from a given string. It does
-    // so by going through the string character by character and trying to keep track of whether we currently
-    // are in a string or identifier and only removing those parts starting with '--' which are in neither.
-
-    QChar lastChar = 0;
-    QList<QChar> stringChars;
-    for(int i=0; i < s.length(); ++i)
-    {
-        if(lastChar != '\\' && (s.at(i) == '\'' || s.at(i) == '"' || s.at(i) == '`'))
-        {
-            if(!stringChars.empty() && stringChars.last() == s.at(i))
-                stringChars.removeLast();
-            else if(!(!stringChars.empty() && (stringChars.last() != '\'' || stringChars.last() != '"')) || stringChars.empty())
-                stringChars.push_back(s.at(i));
-        } else if(stringChars.empty() && s.at(i) == '-' && lastChar == '-') {
-            int nextNL = s.indexOf('\n', i);
-            if(nextNL >= 0)
-                return removeComments(s.remove(i-1, nextNL - i + 2));
-            else
-                return s.left(i-1);
-        }
-
-        lastChar = s.at(i);
-    }
-
-    return s;
-}
 }
 
 void SqliteTableModel::setQuery(const QString& sQuery, bool dontClearHeaders)
@@ -133,7 +100,9 @@ void SqliteTableModel::setQuery(const QString& sQuery, bool dontClearHeaders)
     if(!m_db->isOpen())
         return;
 
-    m_sQuery = removeComments(sQuery).trimmed();
+    m_sQuery = sQuery.trimmed();
+
+    m_sQuery.remove(QRegExp("(?=\\s*[-]{2})[^'\"\n]*($|\\n)"));
 
     // do a count query to get the full row count in a fast manner
     m_rowCount = getQueryRowCount();
@@ -251,18 +220,29 @@ QVariant SqliteTableModel::data(const QModelIndex &index, int role) const
         while(index.row() >= m_data.size() && canFetchMore())
             const_cast<SqliteTableModel*>(this)->fetchMore();   // Nothing evil to see here, move along
 
-        if(role == Qt::DisplayRole && m_data.at(index.row()).at(index.column()).left(1024).contains('\0'))
-            return "BLOB";
-        else if(role == Qt::DisplayRole && m_data.at(index.row()).at(index.column()).isNull())
+        if(role == Qt::DisplayRole && m_data.at(index.row()).at(index.column()).isNull())
+        {
             return PreferencesDialog::getSettingsValue("databrowser", "null_text").toString();
-        else
+        } else if(role == Qt::DisplayRole && isBinary(index)) {
+            return "BLOB";
+        } else if(role == Qt::DisplayRole) {
+            int limit = PreferencesDialog::getSettingsValue("databrowser", "symbol_limit").toInt();
+            QByteArray displayText = m_data.at(index.row()).at(index.column());
+            if (displayText.length() > limit) {
+                // Add "..." to the end of truncated strings
+                return decode(displayText.left(limit).append(" ..."));
+            } else {
+                return decode(displayText);
+            }
+        } else {
             return decode(m_data.at(index.row()).at(index.column()));
+        }
     } else if(role == Qt::FontRole) {
         QFont font;
         if(m_data.at(index.row()).at(index.column()).isNull() || isBinary(index))
             font.setItalic(true);
         return font;
-    } else if(role == Qt::TextColorRole) {
+    } else if(role == Qt::ForegroundRole) {
         if(m_data.at(index.row()).at(index.column()).isNull())
             return QColor(PreferencesDialog::getSettingsValue("databrowser", "null_fg_colour").toString());
         else if (isBinary(index))
@@ -289,12 +269,26 @@ sqlb::ForeignKeyClause SqliteTableModel::getForeignKeyClause(int column) const
 {
     DBBrowserObject obj = m_db->getObjectByName(m_sTable);
     if(obj.getname().size())
-        return obj.table.fields().at(column)->foreignKey();
+        // Note that the rowid column has number -1 here, it can safely be excluded since there will never be a
+        // foreign key on that column.
+        if (column >= 0 && column < obj.table.fields().count())
+        {
+            return obj.table.fields().at(column)->foreignKey();
+        } else {
+            return sqlb::ForeignKeyClause();
+        }
     else
         return sqlb::ForeignKeyClause();
 }
 
 bool SqliteTableModel::setData(const QModelIndex& index, const QVariant& value, int role)
+{
+    // This function is for in-place editing.
+    // So, BLOB flag is false every times.
+    return setTypedData(index, false, value, role);
+}
+
+bool SqliteTableModel::setTypedData(const QModelIndex& index, bool isBlob, const QVariant& value, int role)
 {
     if(index.isValid() && role == Qt::EditRole)
     {
@@ -306,7 +300,7 @@ bool SqliteTableModel::setData(const QModelIndex& index, const QVariant& value,
         if(oldValue == newValue && oldValue.isNull() == newValue.isNull())
             return true;
 
-        if(m_db->updateRecord(m_sTable, m_headers.at(index.column()), m_data[index.row()].at(0), newValue, isBinary(index)))
+        if(m_db->updateRecord(m_sTable, m_headers.at(index.column()), m_data[index.row()].at(0), newValue, isBlob))
         {
             // Only update the cache if this row has already been read, if not there's no need to do any changes to the cache
             if(index.row() < m_data.size())
@@ -425,6 +419,26 @@ bool SqliteTableModel::removeRows(int row, int count, const QModelIndex& parent)
     return true;
 }
 
+QModelIndex SqliteTableModel::dittoRecord(int old_row)
+{
+    int firstEditedColumn = 0;
+    int new_row = rowCount() - 1;
+
+    sqlb::Table t = sqlb::Table::parseSQL(m_db->getObjectByName(m_sTable).getsql()).first;
+
+    for (int col = 0; col < t.fields().size(); ++col) {
+        if (!t.fields().at(col)->primaryKey()) {
+            if (!firstEditedColumn)
+                firstEditedColumn = col + 1;
+
+            QVariant value = data(index(old_row, col + 1), Qt::EditRole);
+            setData(index(new_row, col + 1), value);
+        }
+    }
+
+    return index(new_row, firstEditedColumn);
+}
+
 void SqliteTableModel::fetchData(unsigned int from, unsigned to)
 {
     int currentsize = m_data.size();
@@ -471,8 +485,12 @@ void SqliteTableModel::fetchData(unsigned int from, unsigned to)
     }
     sqlite3_finalize(stmt);
 
-    beginInsertRows(QModelIndex(), currentsize, m_data.size()-1);
-    endInsertRows();
+    // Check if there was any new data
+    if(m_data.size() > currentsize)
+    {
+        beginInsertRows(QModelIndex(), currentsize, m_data.size()-1);
+        endInsertRows();
+    }
 }
 
 void SqliteTableModel::buildQuery()
@@ -618,7 +636,7 @@ void SqliteTableModel::clearCache()
 
 bool SqliteTableModel::isBinary(const QModelIndex& index) const
 {
-    return m_vDataTypes.at(index.column()) == SQLITE_BLOB;
+    return m_data.at(index.row()).at(index.column()).left(1024).contains('\0');
 }
 
 QByteArray SqliteTableModel::encode(const QByteArray& str) const
